.. currentmodule:: pyisbn

Handling ISBNs
==============

The :py:class:`Isbn` supports SBNs, ISBN-10 and -13.  If you're handling
multiple inputs it is easiest to use this class.

.. autoclass:: Isbn
